@@ -529,6 +529,10 @@ arch_apply_relocation(struct obj_file *f,
     /* Easy. */
     break;
 
+  case R_PARISC_SEGREL32:
+    v -= f->baseaddr;
+    break;
+
   case R_PARISC_DPREL21L:
   case R_PARISC_DPREL14R:
     v -= dp;
@@ -566,9 +570,10 @@ arch_apply_relocation(struct obj_file *f,
     case R_PARISC_DIR32:
     case R_PARISC_PLABEL32:
     case R_PARISC_PCREL17F:
+    case R_PARISC_SEGREL32:
       fsel = e_fsel;
       break;
-	
+
     case R_PARISC_DPREL21L:
     case R_PARISC_DIR21L:
       fsel = e_lrsel;
@@ -602,6 +607,7 @@ arch_apply_relocation(struct obj_file *f,
     {
     case R_PARISC_DIR32:
     case R_PARISC_PLABEL32:
+    case R_PARISC_SEGREL32:
       r_format = 32;
       break;
 
