@@ -22,7 +22,7 @@
  * Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  */
 
-#ident "$Id: obj_hppa64.c 1.1 Fri, 05 Jan 2001 12:45:19 +1100 kaos $"
+#ident "$Id: obj_hppa64.c 1.2 Wed, 28 Mar 2001 20:49:06 +1000 kaos $"
 
 #include <string.h>
 #include <assert.h>
@@ -361,6 +361,7 @@ arch_create_got(struct obj_file *f)
 		need_stub = TRUE;
 		break;
 	    case R_PARISC_DIR64:
+	    case R_PARISC_SEGREL32:
 		break;
 	    case R_PARISC_FPTR64:
 		/* This is a simple OPD entry (only created for local symbols,
@@ -597,6 +598,11 @@ arch_apply_relocation(struct obj_file *f,
 	    loc[1] = v;
 	}
 	break;
+    case R_PARISC_SEGREL32:
+	{
+	    loc[0] = v - f->baseaddr;
+	}
+	break;
     case R_PARISC_FPTR64:
 	{
 	    assert(isym != NULL);
