@@ -21,7 +21,7 @@
    along with this program; if not, write to the Free Software Foundation,
    Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.  */
 
-#ident "$Id: obj_load.c 1.1 Fri, 05 Jan 2001 12:45:19 +1100 kaos $"
+#ident "$Id: obj_load.c 1.2 Wed, 21 Mar 2001 12:45:58 +1100 kaos $"
 
 #include <alloca.h>
 #include <string.h>
@@ -52,7 +52,7 @@ obj_load (int fp, Elf32_Half e_type, const char *filename)
   gzf_lseek(fp, 0, SEEK_SET);
   if (gzf_read(fp, &f->header, sizeof(f->header)) != sizeof(f->header))
     {
-      error("error reading ELF header %s: %m", filename);
+      error("cannot read ELF header from %s", filename);
       return NULL;
     }
 
