@@ -19,7 +19,7 @@
    along with this program; if not, write to the Free Software Foundation,
    Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.  */
 
-#ident "$Id: obj_s390.c 1.1 Fri, 05 Jan 2001 12:45:19 +1100 kaos $"
+#ident "$Id: obj_s390.c 1.2 Sun, 25 Mar 2001 21:13:48 +1000 kaos $"
 
 #include <string.h>
 #include <assert.h>
@@ -227,15 +227,15 @@ arch_init_module (struct obj_file *f, struct module *m)
   return 1;
 }
 
-int         
+int
 arch_finalize_section_address(struct obj_file *f, Elf32_Addr base)
-{    
+{
   int  i, n = f->header.e_shnum;
-             
+
   f->baseaddr = base;
   for (i = 0; i < n; ++i)
     f->sections[i]->header.sh_addr += base;
-  return 1;  
+  return 1;
 }
 
 int
