@@ -77,7 +77,7 @@ char *aliaslist[] =
 	"block-major-44 ftl",		/* from David Woodhouse <dwmw2@infradead.org> */
 	"block-major-56 ide-probe-mod",
 	"block-major-57 ide-probe-mod",
-	"block-major-58 lvm-mod"
+	"block-major-58 lvm-mod",
 	"block-major-88 ide-probe-mod",
 	"block-major-89 ide-probe-mod",
 	"block-major-90 ide-probe-mod",
@@ -130,7 +130,7 @@ char *aliaslist[] =
 	"char-major-99 ppdev",
 	"char-major-107 3dfx", /* from Tigran Aivazian <tigran@sco.COM> */
 	"char-major-108 ppp_generic",
-	"char-major-109 lvm-mod"
+	"char-major-109 lvm-mod",
 	"char-major-161 ircomm-tty",
 
 	"dos msdos",
